# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/load_defautls.ipynb (unless otherwise specified).

__all__ = ['ifexists', 'ifnone']

# Cell

from .loader import os
from .paths import loaddill

from fastcore.basics import ifnone

ifnone = ifnone

def ifexists(fpath, default):
    if os.path.exists(fpath):
        return loaddill(fpath)
    else:
        return default